@@ -30,8 +30,8 @@ Storm integration for Kiwi
 from storm.expr import And, Or, Like, Not, Alias, NamedFunc
 
 from kiwi.db.query import NumberQueryState, StringQueryState, \
-     DateQueryState, DateIntervalQueryState, QueryExecuter, \
-     NumberIntervalQueryState
+    DateQueryState, DateIntervalQueryState, QueryExecuter, \
+    NumberIntervalQueryState, BoolQueryState
 from kiwi.interfaces import ISearchFilter
 
 # FIXME: make this usable outside of stoqlib
@@ -49,9 +49,9 @@ class Date(NamedFunc):
 class StormQueryExecuter(QueryExecuter):
     """Execute queries from a storm database"""
 
-    def __init__(self, conn=None):
+    def __init__(self, store=None):
         QueryExecuter.__init__(self)
-        self.conn = conn
+        self.store = store
         self.table = None
         self._query_callbacks = []
         self._filter_query_callbacks = {}
@@ -105,7 +105,7 @@ class StormQueryExecuter(QueryExecuter):
         if self._having:
             having = And(self._having)
 
-        result = self._query(query, having, self.conn)
+        result = self._query(query, having, self.store)
         return result
         #return result.config(limit=self.get_limit())
 
@@ -144,7 +144,7 @@ class StormQueryExecuter(QueryExecuter):
         """
         Overrides the default query mechanism.
         :param callback: a callable which till take two arguments:
-          (query, connection)
+          (query, store)
         """
         if callback is None:
             callback = self._default_query
@@ -154,9 +154,20 @@ class StormQueryExecuter(QueryExecuter):
         self._query = callback
 
     # Basically stolen from sqlobject integration
-    def _default_query(self, query, having, conn):
-        # FIXME: work outside of sqlobject emulation layer
-        return self.table.select(query, having=having, connection=conn)
+    def _default_query(self, query, having, store):
+        # Remove this once we figure out the viewable
+        if not hasattr(self.table, '__storm_table__'):
+            return self.table.select(query, having=having, store=store)
+
+        if query:
+            results = store.find(self.table, query)
+        else:
+            results = store.find(self.table)
+
+        if having:
+            results = results.having(having)
+
+        return results
 
     def _construct_state_query(self, table, state, columns):
         queries = []
@@ -180,6 +191,8 @@ class StormQueryExecuter(QueryExecuter):
                 query = self._parse_date_state(state, table_field)
             elif isinstance(state, DateIntervalQueryState):
                 query = self._parse_date_interval_state(state, table_field)
+            elif isinstance(state, BoolQueryState):
+                query = self._parse_bool_state(state, table_field)
             else:
                 raise NotImplementedError(state.__class__.__name__)
             if query:
@@ -222,3 +235,6 @@ class StormQueryExecuter(QueryExecuter):
             queries.append(Date(table_field) <= Date(state.end))
         if queries:
             return And(*queries)
+
+    def _parse_bool_state(self, state, table_field):
+        return table_field == state.value
