@@ -183,9 +183,6 @@ import warnings
 
 import gobject
 
-if gobject.pygtk_version <= (2, 8):
-    raise RuntimeError("PyGTK 2.8 or later is required for kiwi.tasklet")
-
 _event = None
 
 
@@ -340,8 +337,8 @@ class WaitForIO(WaitCondition):
 
         WaitCondition.__init__(self)
         self.filedes = filedes
-        self._condition = condition # listen condition
-        self.condition = None # last occurred condition
+        self._condition = condition  # listen condition
+        self.condition = None  # last occurred condition
         self._callback = None
         self._id = None
         self._priority = priority
@@ -365,8 +362,8 @@ class WaitForIO(WaitCondition):
                 else:
                     filedes = self.filedes.fileno()
                 self._id = gobject.io_add_watch(filedes, self._condition,
-                                                 self._io_cb,
-                                                 priority=self._priority)
+                                                self._io_cb,
+                                                priority=self._priority)
 
     def disarm(self):
         '''Overrides WaitCondition.disarm'''
@@ -767,7 +764,7 @@ class Tasklet(object):
             assert isinstance(gen, types.GeneratorType)
             self.gen = gen
         if start:
-            self._next_round() # bootstrap
+            self._next_round()  # bootstrap
 
     def start(self):
         """Starts the execution of the task, for use with tasklets
@@ -826,7 +823,7 @@ class Tasklet(object):
     def _next_round(self):
         assert self.state == Tasklet.STATE_SUSPENDED
         old_wait_list = self.wait_list
-        while True: # loop while tasklet yields tasklet.post_message(...)
+        while True:  # loop while tasklet yields tasklet.post_message(...)
 
             gen_value = self._invoke()
             if gen_value is None:
@@ -837,7 +834,7 @@ class Tasklet(object):
                 self.state = Tasklet.STATE_MSGSEND
                 msg.sender = self
                 msg.dest.send_message(msg)
-                continue # loop because we posted a message
+                continue  # loop because we posted a message
             elif isinstance(gen_value, tuple):
                 self.wait_list = list(gen_value)
             elif isinstance(gen_value, list):
@@ -861,7 +858,7 @@ class Tasklet(object):
             msg = self._dispatch_message()
             if msg is not None:
                 self._event = msg
-                continue ## send a message
+                continue  # send a message
 
             break
 
@@ -884,12 +881,12 @@ class Tasklet(object):
         if __debug__:
             self._message_queue = [msg
                                    for msg in self._message_queue
-                                       if _get_action(msg) != Message.DISCARD]
+                                   if _get_action(msg) != Message.DISCARD]
         else:
             ## slightly more efficient version of the above
             self._message_queue = [msg for msg in self._message_queue
-                if (self._message_actions.get(msg.name, Message.DISCARD)
-                    != Message.DISCARD)]
+                                   if (self._message_actions.get(msg.name, Message.DISCARD)
+                                       != Message.DISCARD)]
 
         ## find next ACCEPT-able message from queue, and pop it out
         for idx, msg in enumerate(self._message_queue):
@@ -939,7 +936,7 @@ class Tasklet(object):
 
         '''
         handle = hash(callback)
-        while handle in self._join_callbacks: # handle collisions
+        while handle in self._join_callbacks:  # handle collisions
             handle += 1
         self._join_callbacks[handle] = callback, extra_args
         return handle
