@@ -20,8 +20,10 @@
 # Author(s): Johan Dahlin <jdahlin@async.com.br>
 #
 
+import contextlib
 import os
 import gettext
+import warnings
 
 import glib
 import atk
@@ -37,7 +39,7 @@ _IMAGE_TYPES = {
     gtk.MESSAGE_WARNING: gtk.STOCK_DIALOG_WARNING,
     gtk.MESSAGE_QUESTION: gtk.STOCK_DIALOG_QUESTION,
     gtk.MESSAGE_ERROR: gtk.STOCK_DIALOG_ERROR,
-    }
+}
 
 _BUTTON_TYPES = {
     gtk.BUTTONS_NONE: (),
@@ -48,7 +50,7 @@ _BUTTON_TYPES = {
                          gtk.STOCK_YES, gtk.RESPONSE_YES),
     gtk.BUTTONS_OK_CANCEL: (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                             gtk.STOCK_OK, gtk.RESPONSE_OK)
-    }
+}
 
 
 class HIGAlertDialog(gtk.Dialog):
@@ -153,7 +155,7 @@ class BaseDialog(gtk.Dialog):
 
 
 def messagedialog(dialog_type, short, long=None, parent=None,
-                  buttons=gtk.BUTTONS_OK, default=-1):
+                  buttons=gtk.BUTTONS_OK, default=-1, bold=True):
     """Create and show a MessageDialog.
 
     :param dialog_type: one of constants
@@ -176,6 +178,7 @@ def messagedialog(dialog_type, short, long=None, parent=None,
       or a tuple or 2-sized tuples representing label and response. If label
       is a stock-id a stock icon will be displayed.
     :param default: optional default response id
+    :param bold: If the short message should be formatted to bold
     """
     if buttons in (gtk.BUTTONS_NONE, gtk.BUTTONS_OK, gtk.BUTTONS_CLOSE,
                    gtk.BUTTONS_CANCEL, gtk.BUTTONS_YES_NO,
@@ -197,7 +200,7 @@ def messagedialog(dialog_type, short, long=None, parent=None,
         for text, response in buttons:
             d.add_buttons(text, response)
 
-    d.set_primary(short)
+    d.set_primary(short, bold=bold)
 
     if long:
         if isinstance(long, gtk.Widget):
@@ -221,7 +224,7 @@ def messagedialog(dialog_type, short, long=None, parent=None,
 
 
 def _simple(type, short, long=None, parent=None, buttons=gtk.BUTTONS_OK,
-          default=-1):
+            default=-1):
     if buttons == gtk.BUTTONS_OK:
         default = gtk.RESPONSE_OK
     return messagedialog(type, short, long,
@@ -250,64 +253,101 @@ def yesno(text, parent=None, default=gtk.RESPONSE_YES,
                          buttons=buttons, default=default)
 
 
-def open(title='', parent=None, patterns=None, folder=None, filter=None,
-         with_file_chooser=False):
-    """Displays an open dialog.
-    :param title: the title of the folder, defaults to 'Select folder'
-    :param parent: parent gtk.Window or None
-    :param patterns: a list of pattern strings ['*.py', '*.pl'] or None
-    :param folder: initial folder or None
-    :param filter: a filter to use or None, is incompatible with patterns
-    """
+@contextlib.contextmanager
+def selectfile(title='', parent=None, folder=None, filters=[]):
+    """Creates and returns a gtk.FileChooserDialog.
 
-    ffilter = filter
-    if patterns and ffilter:
-        raise TypeError("Can't use patterns and filter at the same time")
+    To run the dialog, the user apps should do:
 
-    filechooser = gtk.FileChooserDialog(title or _('Open'),
+        >>> from kiwi.ui.dialogs import selectfile
+        >>> with selectfile(...) as sf:
+        >>>     sf.run()
+        >>>     filename = sf.get_filename()
+        >>>     if not filename:
+        >>>         return
+
+    :param title: the title of the folder, defaults to 'Select file'
+    :param parent: parent gtk.Window (defaults to ``None``)
+    :param folder: initial folder (defaults to ``None``, which open current
+      folder)
+    :param filters: a list of filters to use, is incompatible with patterns"""
+
+    filechooser = gtk.FileChooserDialog(title or _('Select file'),
                                         parent,
                                         gtk.FILE_CHOOSER_ACTION_OPEN,
                                         (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                          gtk.STOCK_OPEN, gtk.RESPONSE_OK))
 
-    if patterns or ffilter:
-        if not ffilter:
-            ffilter = gtk.FileFilter()
-            for pattern in patterns:
-                ffilter.add_pattern(pattern)
-        if type(ffilter) != list:
-            ffilter = [ffilter]
-        for f in ffilter:
-            filechooser.add_filter(f)
-    filechooser.set_default_response(gtk.RESPONSE_OK)
+    for f in filters:
+        filechooser.add_filter(f)
 
     if folder:
         filechooser.set_current_folder(folder)
 
-    response = filechooser.run()
-    if response != gtk.RESPONSE_OK:
-        if with_file_chooser:
-            return None, filechooser
+    filechooser.set_default_response(gtk.RESPONSE_OK)
+
+    try:
+        yield filechooser
+    finally:
         filechooser.destroy()
-        return
 
-    path = filechooser.get_filename()
-    if path and os.access(path, os.R_OK):
+
+def open(title='', parent=None, patterns=None, folder=None, filters=None,
+         with_file_chooser=False, filter=None):
+    """Temporarily available to allow deprecated use of kiwi's open() function.
+      Will be removed eventually.
+    :param title: refer to selectfile()
+    :param parent: refer to selectfile()
+    :param folder: refer to selectfile()
+    :param filters: refer to selectfile()
+    :param with_file_chooser: returns filechooser with filename selected"""
+
+    warnings.warn('use selectfile() instead of open()', DeprecationWarning,
+                  stacklevel=2)
+
+    if filter:
+        if filters:
+            warnings.warn('do not use filter, being ignored',
+                          DeprecationWarning, stacklevel=2)
+        else:
+            warnings.warn('use argument filters instead of filter',
+                          DeprecationWarning, stacklevel=2)
+            filters = filter
+
+    if patterns:
+        if filters:
+            warnings.warn('do not use patterns, use gtk.FileFilter instead',
+                          DeprecationWarning, stacklevel=2)
+        else:
+            file_filter = gtk.FileFilter()
+            if type(patterns) != list:
+                patterns = [patterns]
+            for pattern in patterns:
+                file_filter.add_pattern(pattern)
+
+    with selectfile(title='', parent=parent, folder=folder,
+                    filters=[file_filter]) as sf:
+
+        sf.run()
+        path = sf.get_filename()
+        if not path:
+            if with_file_chooser:
+                return None, sf
+            return
+
+        if os.access(path, os.R_OK):
+            if with_file_chooser:
+                return path, sf
+            return path
+
+        abspath = os.path.abspath(path)
+
+        error(_('Could not open file "%s"') % abspath,
+              _('The file "%s" could not be opened. '
+                'Permission denied.') % abspath)
+
         if with_file_chooser:
-            return path, filechooser
-        filechooser.destroy()
-        return path
-
-    abspath = os.path.abspath(path)
-
-    error(_('Could not open file "%s"') % abspath,
-          _('The file "%s" could not be opened. '
-            'Permission denied.') %  abspath)
-
-    if with_file_chooser:
-        return None, filechooser
-    filechooser.destroy()
-    return
+            return None, sf
 
 
 def selectfolder(title='', parent=None, folder=None):
@@ -343,7 +383,7 @@ def selectfolder(title='', parent=None, folder=None):
 
     error(_('Could not select folder "%s"') % abspath,
           _('The folder "%s" could not be selected. '
-            'Permission denied.') %  abspath)
+            'Permission denied.') % abspath)
 
     filechooser.destroy()
     return
@@ -355,6 +395,7 @@ def ask_overwrite(filename, parent=None):
     text = ('<span weight="bold" size="larger">%s</span>\n\n%s\n'
             % (submsg1, submsg2))
     result = messagedialog(gtk.MESSAGE_ERROR, text, parent=parent,
+                           bold=False,
                            buttons=((gtk.STOCK_CANCEL,
                                      gtk.RESPONSE_CANCEL),
                                     (_("Replace"),
