@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2012 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2012-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -40,6 +40,7 @@ import gtk
 from kiwi.currency import currency
 from kiwi.interfaces import IProxyWidget
 from kiwi.ui.delegates import SlaveDelegate
+from kiwi.ui.widgets.checkbutton import ProxyCheckButton
 from kiwi.ui.widgets.colorbutton import ProxyColorButton
 from kiwi.ui.widgets.combo import ProxyComboEntry
 from kiwi.ui.widgets.combobox import ProxyComboBox
@@ -52,42 +53,40 @@ _ = lambda m: gettext.dgettext('kiwi', m)
 
 
 class Field(gobject.GObject):
-    """
-    Properties
-    ==========
-      - B{data_type}: string
-        - Used by proxy_widgets
-      - B{mandatory}: bool I{False}
-        - Used by proxy_widgets
-      - B{label}: string I{None}
-        - Text of the label that will be next to the field,
-          Can be None for not displaying any label at all
-      - B{label_attribute}: string I{None}
-        - Name of the label widget inside the view, None
-          means it should be model_attribute + '_lbl'
-      - B{has_add_button}: bool I{False}
-        - If we should add an add button next to the widget
-      - B{has_edit_button}: bool I{False}
-        - If we should add an edit button next to the widget
-      - B{proxy}: bool I{False}
-        - If this field should be added to a proxy
-    """
 
-    # This is used to sort class variables in creation order
-    # which is essentially the same thing as the order in the
-    # source file, idea borrowed from Django
+    #: This is used to sort class variables in creation order
+    #: which is essentially the same thing as the order in the
+    #: source file, idea borrowed from Django
     global_sort_key = 0
 
+    #: Used by proxy_widgets
     data_type = gobject.property(type=object)
+
+    #: Used by proxy_widgets
     mandatory = gobject.property(type=bool, default=False)
+
+    #: Text of the label that will be next to the field,
+    #: Can be None for not displaying any label at all
     label = gobject.property(type=str)
+
+    #: Name of the label widget inside the view, None
+    #: means it should be model_attribute + '_lbl'
     label_attribute = gobject.property(type=str)
+
+    #: If we should add an add button next to the widget
     has_add_button = gobject.property(type=bool, default=False)
+
+    #: If we should add an edit button next to the widget
     has_edit_button = gobject.property(type=bool, default=False)
+
+    #: If we should add a delete button next to the widget
+    has_delete_button = gobject.property(type=bool, default=False)
+
+    #: If this field should be added to a proxy
     proxy = gobject.property(type=bool, default=False)
 
-    # This can be used by subclasses to override the default
-    # values for properties
+    #: This can be used by subclasses to override the default
+    #: values for properties
     default_overrides = {}
 
     def __init__(self, label='', **kwargs):
@@ -98,6 +97,7 @@ class Field(gobject.GObject):
         self.widget = None
         self.add_button = None
         self.edit_button = None
+        self.delete_button = None
 
         # Label is a positional argument for convienience, convert it to
         # a keyword argument so it can be set via GObject.__init__
@@ -136,8 +136,10 @@ class Field(gobject.GObject):
         self.view = form.view
         self._build_add_button()
         self._build_edit_button()
+        self._build_delete_button()
         self.attach()
-        self.label_widget.show()
+        if self.label_widget:
+            self.label_widget.show()
         self.widget.show()
 
     def _build_add_button(self):
@@ -161,6 +163,17 @@ class Field(gobject.GObject):
             self.label.lower(), ))
         self.edit_button.set_sensitive(False)
 
+    def _build_delete_button(self):
+        if not self.has_delete_button:
+            return
+
+        self.delete_button = self.create_button(gtk.STOCK_DELETE)
+        self.delete_button.connect('clicked', self.delete_button_clicked)
+        self.delete_button.set_use_stock(True)
+        self.delete_button.set_tooltip_text(_("Delete the selected %s") % (
+            self.label.lower(), ))
+        self.delete_button.set_sensitive(False)
+
     def _on_widget__content_changed(self, widget):
         self.content_changed()
 
@@ -182,12 +195,18 @@ class Field(gobject.GObject):
             self.add_button.set_sensitive(value)
         if self.edit_button:
             self.edit_button.set_sensitive(value)
+        if self.delete_button:
+            self.delete_button.set_sensitive(value)
 
     # Overridables
 
     def build_label(self):
+        # This method will be overridden by some fields that don't need a
+        # label_widget, because they carry their own label. Because of this,
+        # we need to verify if label_widget exists everytime we use it.
         label_widget = ProxyLabel()
-        label_widget.set_markup(self.label + ':')
+        if self.label:
+            label_widget.set_markup(self.label + ':')
         label_widget.set_alignment(1.0, 0.5)
         return label_widget
 
@@ -214,15 +233,34 @@ class Field(gobject.GObject):
     def edit_button_clicked(self, button):
         raise NotImplementedError
 
+    def delete_button_clicked(self, button):
+        raise NotImplementedError
+
     def content_changed(self):
         pass
 
 gobject.type_register(Field)
 
 
+class BoolField(Field):
+    """
+    I am a field representing a yes/no choice,
+    rendered as a check button.
+    """
+    widget_data_type = bool
+
+    def build_widget(self):
+        widget = ProxyCheckButton(self.label)
+        return widget
+
+    def build_label(self):
+        return None
+
+
 class TextField(Field):
     """
-    I am a text field with one line, editable by the user
+    I am a text field with one line, editable by the user,
+    rendered as an entry.
     """
     editable = gobject.property(type=bool, default=True)
     input_mask = gobject.property(type=object)
@@ -245,7 +283,8 @@ gobject.type_register(TextField)
 
 class ChoiceField(Field):
     """
-    I am a field representing a choice, normally a ComboBox
+    I am a field representing a set of choices,
+    rendered as a ComboBox or ComboEntry.
     """
     values = gobject.property(type=object)
     use_entry = gobject.property(type=bool, default=False)
@@ -266,7 +305,8 @@ class ChoiceField(Field):
 
 class PriceField(Field):
     """
-    I am a field representing a price, contain a currency symbol, right-aligned etc.
+    I am a field representing a price, contain a currency symbol,
+    right-aligned etc, rendered as an entry.
     """
     widget_data_type = currency
 
@@ -278,7 +318,7 @@ class PriceField(Field):
 class DateField(Field):
     """
     I am a field representing a date where the user can chose
-    a date from a calendar.
+    a date from a calendar, rendered as a date entry.
     """
     widget_data_type = datetime.date
 
@@ -289,9 +329,10 @@ class DateField(Field):
 
 class ColorField(Field):
     """
-    I am a field representing a color.
+    I am a field representing a color,
+    rendered as a color button.
     """
-    widget_data_type = str
+    widget_data_type = unicode
 
     def build_widget(self):
         button = ProxyColorButton()
@@ -300,7 +341,8 @@ class ColorField(Field):
 
 class NumericField(Field):
     """
-    I am a field representing a numeric value.
+    I am a field representing a numeric value,
+    rendered as a spin button.
     """
     widget_data_type = Decimal
 
@@ -313,7 +355,8 @@ class NumericField(Field):
 
 class PercentageField(Field):
     """
-    I am a field representing a percentage.
+    I am a field representing a percentage,
+    rendered as a spin button.
     """
     widget_data_type = Decimal
 
@@ -327,16 +370,23 @@ class PercentageField(Field):
 
 
 class MultiLineField(Field):
+    """
+    I am a text field with multiple lines,
+    rendered as a text view.
+    """
     widget_data_type = unicode
 
     def build_widget(self):
         from kiwi.ui.widgets.textview import ProxyTextView
         widget = ProxyTextView()
+        widget.set_wrap_mode(gtk.WRAP_WORD)
         return widget
 
     def get_attachable_widget(self):
         sw = gtk.ScrolledWindow()
         sw.add(self.widget)
+        sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        sw.set_shadow_type(gtk.SHADOW_OUT)
         sw.show()
         return sw
 
@@ -348,10 +398,11 @@ class FormLayout(object):
     # * call form.build_field(field, field_name) for all fields
     #   that are passed into the constructor
     # * pack the following widgets:
-    #   * field.label_widget
+    #   * field.label_widget (can be None, for BoolFields for example)
     #   * field.widget
     #   * field.add_button (can be None)
     #   * field.edit_button (can be None)
+    #   * field.delete_button (can be None)
     # * setup focus
     # * save the toplevel container as self.widget
     #
@@ -361,28 +412,32 @@ class FormLayout(object):
 
 
 class FormTableLayout(FormLayout):
-    """Most common layout, a table with four columns:
+    """Most common layout, a table with columns:
 
-    +-------+-------+---+----+
-    | Value:|Widget |Add|Edit|
-    +-------+-------+---+----+
-    |  Name:|Widget |Add|Edit|
-    +-------+-------+---+----+
-    | ....  |...... |...|....|
+    +-------+-------+---+----+------+
+    | Value:|Widget |Add|Edit|Delete|
+    +-------+-------+---+----+------+
+    |  Name:|Widget |Add|Edit|Delete|
+    +-------+-------+---+----+------+
+    | ....  |...... |...|....|......|
 
     Each new field is added as another vertical line.
+    Widget will always be visible.
+    Add, Edit, Delete are optional.
+    Value label can be hidden.
     """
     def __init__(self, form, fields):
         FormLayout.__init__(self, form, fields)
-        table = gtk.Table(len(fields), 4, False)
+        table = gtk.Table(len(fields), 5, False)
         table.props.row_spacing = 6
 
         focus_widgets = []
         for i, (field, field_name) in enumerate(fields):
             form.build_field(field, field_name)
-            table.attach(field.label_widget, 0, 1, i, i + 1,
-                         gtk.FILL,
-                         gtk.EXPAND | gtk.FILL, 0, 0)
+            if field.label_widget:
+                table.attach(field.label_widget, 0, 1, i, i + 1,
+                             gtk.FILL,
+                             gtk.EXPAND | gtk.FILL, 0, 0)
             table.attach(field.get_attachable_widget(), 1, 2, i, i + 1,
                          gtk.EXPAND | gtk.FILL,
                          gtk.EXPAND | gtk.FILL, 6, 0)
@@ -394,6 +449,10 @@ class FormTableLayout(FormLayout):
                 table.attach(field.edit_button, 3, 4, i, i + 1,
                              gtk.SHRINK,
                              gtk.EXPAND | gtk.FILL, 0, 0)
+            if field.delete_button:
+                table.attach(field.delete_button, 4, 5, i, i + 1,
+                             gtk.SHRINK,
+                             gtk.EXPAND | gtk.FILL, 0, 0)
             focus_widgets.append(field.widget)
 
         table.set_focus_chain(focus_widgets)
@@ -467,13 +526,17 @@ class BasicForm(SlaveDelegate):
     def build_field(self, field, model_attribute):
         field.attach_form(self, model_attribute)
         setattr(self.main_view, model_attribute, field.widget)
-        setattr(self.main_view, field.label_attribute, field.label_widget)
+        if field.label_widget:
+            setattr(self.main_view, field.label_attribute, field.label_widget)
         if field.has_add_button:
             setattr(self.main_view,
                     field.model_attribute + '_add_button', field.add_button)
         if field.has_edit_button:
             setattr(self.main_view,
                     field.model_attribute + '_edit_button', field.edit_button)
+        if field.has_delete_button:
+            setattr(self.main_view,
+                    field.model_attribute + '_delete_button', field.delete_button)
         self._fields[model_attribute] = field
 
     def populate(self, *args):
