@@ -27,6 +27,7 @@
 """High level wrapper for GtkTreeView"""
 
 import datetime
+import decimal
 import gettext
 import locale
 import pickle
@@ -38,8 +39,8 @@ import gtk
 from gtk import gdk
 
 from kiwi.accessor import kgetattr
-from kiwi.datatypes import converter, number, Decimal, ValidationError
-from kiwi.currency import currency # after datatypes
+from kiwi.datatypes import converter, number, ValidationError
+from kiwi.currency import currency  # after datatypes
 from kiwi.enums import Alignment
 from kiwi.log import Logger
 from kiwi.python import enum, slicerange
@@ -431,7 +432,7 @@ class Column(gobject.GObject):
             for key, value in items:
                 enum_model.append((key.lower().capitalize(), value))
 
-            renderer =  gtk.CellRendererCombo()
+            renderer = gtk.CellRendererCombo()
             renderer.set_property('model', enum_model)
             renderer.set_property('text-column', 0)
             renderer.set_property('has-entry', True)
@@ -562,7 +563,7 @@ class Column(gobject.GObject):
             for row in model:
                 obj = row[COL_MODEL]
                 value = getattr(obj, attr)
-                if value == True:
+                if value:
                     old = obj
                     break
         if old:
@@ -646,13 +647,13 @@ class Column(gobject.GObject):
             else:
                 text = self.format_func(data)
         elif (self.format or
-            data_type == float or
-            data_type == Decimal or
-            data_type == currency or
-            data_type == datetime.date or
-            data_type == datetime.datetime or
-            data_type == datetime.time or
-            issubclass(data_type, enum)):
+              data_type == float or
+              data_type == decimal.Decimal or
+              data_type == currency or
+              data_type == datetime.date or
+              data_type == datetime.datetime or
+              data_type == datetime.time or
+              issubclass(data_type, enum)):
             conv = converter.get_converter(data_type)
             text = conv.as_string(data, format=self.format or None)
         # Actually the expected data type depends on the renderer,
@@ -733,6 +734,11 @@ class SearchColumn(Column):
                              the model.
     """
 
+    #: overrides the function that generates the query to process the search
+    search_func = gobject.property(type=object, default=None)
+    #: names the search interface differently from the column
+    search_label = gobject.property(type=object, default=None)
+
     def __init__(self, attribute, title=None, data_type=None,
                  long_title=None, valid_values=None, search_attribute=None,
                  **kwargs):
@@ -742,8 +748,21 @@ class SearchColumn(Column):
         self.valid_values = valid_values
         self.search_attribute = search_attribute
         self.sensitive = True
+
         Column.__init__(self, attribute, title, data_type, **kwargs)
 
+        search_func = kwargs.get('search_func')
+        if search_func and not callable(search_func):
+            raise TypeError("search_func must be callable")
+
+    def get_search_label(self):
+        """Get the search label for this column.
+          This is normally used when constructing a search filter for this
+          column.
+          :returns: the search label
+        """
+        return self.search_label or self.long_title or self.title
+
 
 class ColoredColumn(Column):
     """
@@ -814,7 +833,7 @@ class _ContextMenu(gtk.Menu):
         self._signal_ids = []
         self._treeview = treeview
         self._treeview.connect('columns-changed',
-                              self._on_treeview__columns_changed)
+                               self._on_treeview__columns_changed)
         self._create()
 
     def clean(self):
@@ -880,7 +899,7 @@ class _ContextMenu(gtk.Menu):
             # If there's only one menuitem less to select, set
             # it to insensitive
             active_children = [child for child in children
-                                         if child.get_active()]
+                               if child.get_active()]
             if len(active_children) == 1:
                 active_children[0].set_sensitive(False)
 
@@ -1121,7 +1140,7 @@ class ObjectList(gtk.HBox):
         elif isinstance(arg, slice):
             model = self._model
             return [model[item][COL_MODEL]
-                        for item in slicerange(arg, len(self._model))]
+                    for item in slicerange(arg, len(self._model))]
         else:
             raise TypeError("argument arg must be int, gtk.Treeiter or "
                             "slice, not %s" % type(arg))
@@ -1280,7 +1299,7 @@ class ObjectList(gtk.HBox):
             _, paths = selection.get_selected_rows()
             if paths:
                 selected_instances = [model[path][COL_MODEL]
-                                          for (path,) in paths]
+                                      for (path,) in paths]
 
         iters = self._iters
         prev = None
@@ -1336,7 +1355,7 @@ class ObjectList(gtk.HBox):
                 if sorted:
                     raise ValueError("Can't make column %s sorted, column"
                                      " %s is already set as sortable" % (
-                        column.attribute, sorted))
+                                         column.attribute, sorted))
                 sorted = column.attribute
             if column.expand:
                 expand = True
@@ -2026,7 +2045,7 @@ class ObjectList(gtk.HBox):
         """
         return [
             ('OBJECTLIST_ROW', 0, 10),
-            ]
+        ]
 
     def set_message(self, markup):
         """Adds a message on top of the treeview rows
