@@ -311,7 +311,7 @@ class SlaveView(gobject.GObject):
             return []
 
         return [widget for widget in self._glade_adaptor.get_widgets()
-                           if isinstance(widget, gtk.Notebook)]
+                if isinstance(widget, gtk.Notebook)]
 
     def _check_reserved(self):
         for reserved in ["widgets", "toplevel", "gladefile",
@@ -389,7 +389,7 @@ class SlaveView(gobject.GObject):
     def _attach_forms(self):
         for holder_name, form in self._forms.items():
             self.attach_slave(holder_name, form)
-            form.populate(self.conn)
+            form.populate(self.store)
             form.add_proxy()
             form.show()
         self._forms_attached = True
@@ -552,7 +552,7 @@ class SlaveView(gobject.GObject):
             if top_widget:
                 allocation = widget.allocation
                 top_allocation = getattr(top_widget, 'allocation', None)
-                assert top_allocation != None
+                assert top_allocation is not None
                 if (top_allocation[0] + top_allocation[1] >
                     allocation[0] + allocation[1]):
                     top_widget = widget
@@ -620,10 +620,10 @@ class SlaveView(gobject.GObject):
 
         shell = slave.get_toplevel()
 
-        if isinstance(shell, (gtk.Window, gtk.Dialog)): # view with toplevel window
+        if isinstance(shell, (gtk.Window, gtk.Dialog)):  # view with toplevel window
             new_widget = shell.get_child()
-            shell.remove(new_widget) # remove from window to allow reparent
-        else: # slaveview
+            shell.remove(new_widget)  # remove from window to allow reparent
+        else:  # slaveview
             new_widget = shell
 
         placeholder = placeholder_widget or self.get_widget(name)
@@ -631,7 +631,7 @@ class SlaveView(gobject.GObject):
 
         if not placeholder:
             raise AttributeError(
-                  "slave container widget `%s' not found" % name)
+                "slave container widget `%s' not found" % name)
 
         # This is for glade-less Views, create an EventBox automatically
         # for a holder
@@ -791,7 +791,7 @@ class SlaveView(gobject.GObject):
         for widget in widgets:
             if not isinstance(widget, gtk.Widget):
                 raise TypeError(
-                "Only Gtk widgets may be passed in list, found\n%s" % widget)
+                    "Only Gtk widgets may be passed in list, found\n%s" % widget)
             if after:
                 widget.connect_after(signal, handler)
             else:
@@ -924,7 +924,7 @@ class SlaveView(gobject.GObject):
         validation_log.info("%s: validate state=%r" % (
             self.__class__.__name__, self._validation))
         # Check if validation really changed
-        if self.is_valid == is_valid and force == False:
+        if self.is_valid == is_valid and not force:
             return
 
         self.is_valid = is_valid
@@ -1060,7 +1060,7 @@ class BaseView(SlaveView):
         is set as a transient for the parent view.
         """
         # Uniconize window if minimized
-        self.toplevel.present() # this call win.show() for us
+        self.toplevel.present()  # this call win.show() for us
         self.check_focus()
         if parent is not None:
             self.set_transient_for(parent)
@@ -1113,7 +1113,7 @@ def _open_glade(view, gladefile, domain):
         raise ValueError("A gladefile wasn't provided.")
     elif not isinstance(gladefile, basestring):
         raise TypeError(
-              "gladefile should be a string, found %s" % type(gladefile))
+            "gladefile should be a string, found %s" % type(gladefile))
 
     if _glade_loader_func:
         return _glade_loader_func(view, gladefile, domain)
